@@ -221,6 +221,7 @@ def write_load_case(load_path, load_cases):
         def_grad_aim = load_case.get('def_grad_aim')
         def_grad_rate = load_case.get('def_grad_rate')
         stress = load_case.get('stress')
+        rot = load_case.get('rotation')
         total_time = load_case['total_time']
         num_increments = load_case['num_increments']
 
@@ -255,7 +256,7 @@ def write_load_case(load_path, load_cases):
                        'masked array.')
                 raise ValueError(msg)
 
-            dg_arr_fmt = format_1D_masked_array(dg_arr.flatten())
+            dg_arr_fmt = format_1D_masked_array(dg_arr.flatten(), fmt='{:.10f}')
             load_case_ln.append(dg_arr_sym + ' ' + dg_arr_fmt)
 
         else:
@@ -272,8 +273,10 @@ def write_load_case(load_path, load_cases):
                 if np.any(dg_arr.mask == stress.mask):
                     raise ValueError(msg)
 
-                dg_arr_fmt = format_1D_masked_array(dg_arr.flatten(), fill_symbol='*')
-                stress_arr_fmt = format_1D_masked_array(stress.flatten(), fill_symbol='*')
+                dg_arr_fmt = format_1D_masked_array(
+                    dg_arr.flatten(), fill_symbol='*', fmt='{:.10f}')
+                stress_arr_fmt = format_1D_masked_array(
+                    stress.flatten(), fill_symbol='*', fmt='{:.10f}')
                 load_case_ln.extend([
                     dg_arr_sym + ' ' + dg_arr_fmt,
                     stress_symbol + ' ' + stress_arr_fmt,
@@ -285,7 +288,7 @@ def write_load_case(load_path, load_cases):
                            'masked array.')
                     raise ValueError(msg)
 
-                stress_arr_fmt = format_1D_masked_array(stress.flatten())
+                stress_arr_fmt = format_1D_masked_array(stress.flatten(), fmt='{:.10f}')
                 load_case_ln.append(stress_symbol + ' ' + stress_arr_fmt)
 
         load_case_ln.extend([
@@ -293,6 +296,18 @@ def write_load_case(load_path, load_cases):
             f'incs {num_increments}'
         ])
 
+        if rot is not None:
+
+            rot = np.array(rot)
+            msg = 'Matrix passed as a rotation is not a rotation matrix.'
+            if not np.allclose(rot.T @ rot, np.eye(3)):
+                raise ValueError(msg)
+            if not np.isclose(np.linalg.det(rot), 1):
+                raise ValueError(msg)
+
+        rot_fmt = format_1D_masked_array(rot.flatten(), fmt='{:.10f}')
+        load_case_ln.append(f'rot {rot_fmt}')
+
         load_case_str = ' '.join(load_case_ln)
         all_load_case.append(load_case_str)
 
